@@ -1,5 +1,5 @@
 package HackaMol::Roles::MolReadRole;
-$HackaMol::Roles::MolReadRole::VERSION = '0.048';
+$HackaMol::Roles::MolReadRole::VERSION = '0.049';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use Carp;
@@ -13,6 +13,7 @@ with qw(
         HackaMol::Roles::ReadYAMLRole
         HackaMol::Roles::ReadZmatRole
         HackaMol::Roles::ReadPdbRole
+        HackaMol::Roles::ReadPdbxRole
         HackaMol::Roles::ReadPdbqtRole
         HackaMol::Roles::ReadXyzRole
 );
@@ -28,7 +29,7 @@ has 'hush_read' => (
 sub read_string_atoms {
     my $self   = shift;
     my $string = shift;  
-    my $type   = shift or croak "must pass format: xyz, pdb, pdbqt, zmat, yaml";
+    my $type   = shift or croak "must pass format: xyz, pdb, cif, pdbqt, zmat, yaml";
 
     open (my $fh, '<', \$string) or croak "unable to open string";
 
@@ -46,6 +47,9 @@ sub read_string_atoms {
     elsif ( $type eq 'zmat') {
         $atoms = $self->read_zmat_atoms($fh);
     }
+    elsif ( $type eq 'cif') {
+        $atoms = $self->read_cif_atoms($fh);
+    }
     elsif ( $type eq 'yaml') {
         $fh->close;
         $fh = Loadtype($type); 
@@ -65,6 +69,22 @@ sub read_file_pdb_parts{
     return $self->read_pdb_parts($fh);    
 }
 
+sub read_file_cif_parts {
+    # temporary, this is getting out of hand!
+    my $self = shift;
+    my $file = shift;
+
+    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
+    my $info = $self->read_cif_info($fh);
+    my @models = $self->read_cif_atoms($fh);
+    $info = $self->read_cif_info($fh,$info);
+    my @mols = map {
+        HackaMol::Molecule->new(
+          name => "model." . $_->[0]->model_num,
+          atoms => $_
+        ) } @models;
+    return ($info, \@mols);
+}
 
 sub read_file_atoms {
     my $self = shift;
@@ -80,6 +100,9 @@ sub read_file_atoms {
     elsif ( $file =~ m/\.pdbqt$/ ) {
         $atoms = $self->read_pdbqt_atoms($fh);
     }
+    elsif ( $file =~ m/\.cif$/ ) {
+        $atoms = $self->read_cif_atoms($fh);
+    }
     elsif ( $file =~ m/\.xyz$/ ) {
         $atoms = $self->read_xyz_atoms($fh);
     }
@@ -111,7 +134,7 @@ HackaMol::Roles::MolReadRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -211,11 +234,13 @@ L<HackaMol::Molecule>
 
 =item * L<HackaMol::Roles::ReadPdbqtRole>
 
+=item * L<HackaMol::Roles::ReadPdbxRole>
+
 =item * L<HackaMol::Roles::ReadXyzRole>
 
 =item * L<HackaMol::Roles::ReadYAMLRole>
 
-=item * L<HackaMol::Roles::ReadYAMLRole|HackaMol::Roles::ReadZmatRole|HackaMol::Roles::ReadPdbRole|HackaMol::Roles::ReadPdbqtRole|HackaMol::Roles::ReadXyzRole>
+=item * L<HackaMol::Roles::ReadYAMLRole|HackaMol::Roles::ReadZmatRole|HackaMol::Roles::ReadPdbRole|HackaMol::Roles::ReadPdbxRole|HackaMol::Roles::ReadPdbqtRole|HackaMol::Roles::ReadXyzRole>
 
 =item * L<HackaMol::Roles::ReadZmatRole>
 
